@@ -1,10 +1,3 @@
-#' drplyr-methods
-#' 
-#' @rdname dplyr-methods
-#' 
-#' @return A tibble
-
-
 #' Arrange rows by column values
 #'
 #'
@@ -16,7 +9,9 @@
 #' need to explicit mention grouping variables (or use  `by_group = TRUE`)
 #' in order to group by them, and functions of variables are evaluated
 #' once per data frame, not once per group.
-#'
+#' 
+#' @importFrom dplyr arrange
+#' 
 #' @details
 #' ## Locales
 #' The sort order for character vectors will depend on the collating sequence
@@ -40,6 +35,10 @@
 #' individual methods for extra arguments and differences in behaviour.
 #'
 #' The following methods are currently available in loaded packages:
+#' 
+#' @rdname dplyr-methods
+#' @name arrange
+#' 
 #' @export
 #' @param .data A data frame, data frame extension (e.g. a tibble), or a
 #'   lazy data frame (e.g. from dbplyr or dtplyr). See *Methods*, below, for
@@ -52,22 +51,7 @@
 #' @examples
 #' `%>%` = magrittr::`%>%`
 #' pbmc_small %>% tidy %>% arrange(nFeature_RNA)
-arrange <- function(.data, ..., .by_group = FALSE) {
-  UseMethod("arrange")
-}
-
-#' @param .by_group If `TRUE`, will sort first by grouping variable. Applies to
-#'   grouped data frames only.
-#' @rdname dplyr-methods
-#' @export
-#'
- 
-#' @inheritParams arrange
-arrange.default <- function(.data, ..., .by_group = FALSE) {
-  
-  dplyr::arrange(.data, ..., .by_group = .by_group)
-  
-}
+NULL
 
 #' @importFrom tibble as_tibble
 #' 
@@ -157,16 +141,22 @@ bind_rows.default <-  function(..., .id = NULL,  add.cell.ids = NULL)
 bind_rows.tidyseurat <- function(..., .id = NULL,  add.cell.ids = NULL)
 {
   
-
-    
   tts = flatten_if(dots_values(...), is_spliced)
-
-  # Check if cell with same name
-  merge(  tts[[1]] ,  tts[[2]]  ,  add.cell.ids = add.cell.ids) %>% tidy
   
+  # Check if cell with same name
+  merge(  tts[[1]] , y = tts[[2]],  add.cell.ids = add.cell.ids) %>% tidy
   
 }
 
+bind_cols_ = function(..., .id = NULL){
+  
+  tts = 	tts = flatten_if(dots_values(...), is_spliced) 
+  
+  tts[[1]]@meta.data = dplyr::bind_cols( tts[[1]]@meta.data, tts[[2]], .id = .id) 
+  
+  tts[[1]]
+  
+}
 
 #' @export
 #' 
@@ -189,20 +179,12 @@ bind_cols.default <-  function(..., .id = NULL)
 #' 
 #' @export
 #' 
-bind_cols.tidyseurat <- function(..., .id = NULL)
-{
-  
-  tts = 	tts = flatten_if(dots_values(...), is_spliced) 
-  
-  tts[[1]]@meta.data = dplyr::bind_cols( tts[[1]]@meta.data, tts[[2]], .id = .id) 
-  
-  tts[[1]]
-  
-}
+bind_cols.tidyseurat <- bind_cols_
 
 
 #' distinct
 #' 
+#' @importFrom dplyr distinct
 #' 
 #' @param .data A tbl. (See dplyr)
 #' @param ... Data frames to combine (See dplyr)
@@ -215,16 +197,11 @@ bind_cols.tidyseurat <- function(..., .id = NULL)
 #' `%>%` = magrittr::`%>%`
 #' pbmc_small %>% tidy %>% distinct(groups)
 #'
+#' @rdname dplyr-methods
+#' @name distinct
+#' 
 #' @export
-distinct <- function (.data, ..., .keep_all = FALSE)  {
-  UseMethod("distinct")
-}
-
-#' @export
-distinct.default <-  function (.data, ..., .keep_all = FALSE)
-{
-  dplyr::distinct(.data, ..., .keep_all = FALSE)
-}
+NULL
 
 #' @export
 distinct.tidyseurat <- function (.data, ..., .keep_all = FALSE)
@@ -247,7 +224,9 @@ distinct.tidyseurat <- function (.data, ..., .keep_all = FALSE)
 #' dplyr is not yet smart enough to optimise filtering optimisation
 #' on grouped datasets that don't need grouped calculations. For this reason,
 #' filtering is often considerably faster on [ungroup()]ed data.
-#'
+#' 
+#' @importFrom dplyr filter
+#' 
 #' @section Useful filter functions:
 #'
 #' * [`==`], [`>`], [`>=`] etc
@@ -289,6 +268,10 @@ distinct.tidyseurat <- function (.data, ..., .keep_all = FALSE)
 #'
 #' The following methods are currently available in loaded packages:
 #' @seealso [filter_all()], [filter_if()] and [filter_at()].
+#' 
+#' @rdname dplyr-methods
+#' @name filter
+#' 
 #' @export
 #' @examples
 #' 
@@ -296,22 +279,16 @@ distinct.tidyseurat <- function (.data, ..., .keep_all = FALSE)
 #' pbmc_small %>% tidy %>% filter(groups == "g1")
 #'
 #' # Learn more in ?dplyr_tidy_eval
- 
-#' @export
-filter <- function (.data, ..., .preserve = FALSE)  {
-  UseMethod("filter")
-}
-
-#' @export
-filter.default <-  function (.data, ..., .preserve = FALSE)
-{
-  dplyr::filter(.data, ..., .preserve = .preserve)
-}
+NULL
 
 #' @export
 filter.tidyseurat <- function (.data, ..., .preserve = FALSE)
 {
   new_meta = .data %>% as_tibble() %>% dplyr::filter( ..., .preserve = .preserve) %>% as_meta_data(.data)
+  
+  # Error if size == 0
+  if(nrow(new_meta) == 0) stop("tidyseurat says: the resulting data container is empty. Seurat does not allow for empty containers.")
+  
   new_obj = subset(.data,   cells = rownames(new_meta ))
   #new_obj@meta.data = new_meta
   
@@ -323,6 +300,7 @@ filter.tidyseurat <- function (.data, ..., .preserve = FALSE)
 #' Group by one or more variables
 #' 
 #' @importFrom dplyr group_by_drop_default
+#' @importFrom dplyr group_by
 #'
 #' @description
 #' Most data operations are done on groups defined by variables.
@@ -351,24 +329,16 @@ filter.tidyseurat <- function (.data, ..., .preserve = FALSE)
 #' individual methods for extra arguments and differences in behaviour.
 #'
 #' Methods available in currently loaded packages:
-#'
+#' 
+#' @rdname dplyr-methods
+#' @name group_by
+#' 
 #' @export
 #' @examples
 #' `%>%` = magrittr::`%>%`
 #' pbmc_small %>% tidy %>% group_by(groups)
 #'
-
- 
-#' @export
-group_by <- function (.data, ..., .add = FALSE, .drop = group_by_drop_default(.data))  {
-  UseMethod("group_by")
-}
-
-#' @export
-group_by.default <-  function (.data, ..., .add = FALSE, .drop = group_by_drop_default(.data))
-{
-  dplyr::group_by(.data, ...,  .drop = .drop)
-}
+NULL
 
 #' @export
 group_by.tidyseurat <- function (.data, ..., .add = FALSE, .drop = group_by_drop_default(.data))
@@ -392,7 +362,9 @@ group_by.tidyseurat <- function (.data, ..., .add = FALSE, .drop = group_by_drop
 #' for each of the summary statistics that you have specified.
 #'
 #' `summarise()` and `summarize()` are synonyms.
-#'
+#' 
+#' @importFrom dplyr summarise
+#' 
 #' @section Useful functions:
 #'
 #' * Center: [mean()], [median()]
@@ -444,21 +416,16 @@ group_by.tidyseurat <- function (.data, ..., .add = FALSE, .drop = group_by_drop
 #' individual methods for extra arguments and differences in behaviour.
 #'
 #' The following methods are currently available in loaded packages:
+#' 
+#' @rdname dplyr-methods
+#' @name summarise
+#' 
 #' @examples
 #' `%>%` = magrittr::`%>%`
 #' pbmc_small %>% tidy %>% summarise(mean(nCount_RNA))
 #'
- 
 #' @export
-summarise <- function (.data, ...)  {
-  UseMethod("summarise")
-}
-
-#' @export
-summarise.default <-  function (.data, ...)
-{
-  dplyr::summarise(.data, ...)
-}
+NULL
 
 #' @export
 summarise.tidyseurat <- function (.data, ...)
@@ -479,7 +446,9 @@ summarise.tidyseurat <- function (.data, ...)
 #' `transmute()` adds new variables and drops existing ones.
 #' New variables overwrite existing variables of the same name.
 #' Variables can be removed by setting their value to `NULL`.
-#'
+#' 
+#' @importFrom dplyr mutate
+#' 
 #' @section Useful mutate functions:
 #'
 #' * [`+`], [`-`], [log()], etc., for their usual mathematical meanings
@@ -502,12 +471,14 @@ summarise.tidyseurat <- function (.data, ...)
 #' as soon as an aggregating, lagging, or ranking function is
 #' involved. Compare this ungrouped mutate:
 #'
-
 #' With the grouped equivalent:
 #'
 #' The former normalises `mass` by the global average whereas the
 #' latter normalises by the averages within gender levels.
-#'
+#' 
+#' @rdname dplyr-methods
+#' @name mutate
+#' 
 #' @export
 #' @inheritParams arrange
 #' @param ... <[`tidy-eval`][dplyr_tidy_eval]> Name-value pairs.
@@ -553,17 +524,7 @@ summarise.tidyseurat <- function (.data, ...)
 #' `%>%` = magrittr::`%>%`
 #' pbmc_small %>% tidy %>% mutate(nFeature_RNA = 1)
 #'
- 
-#' @export
-mutate <- function(.data, ...) {
-  UseMethod("mutate")
-}
-
-#' @export
-mutate.default <-  function(.data, ...)
-{
-  dplyr::mutate(.data, ...)
-}
+NULL
 
 
 #' @importFrom dplyr mutate
@@ -588,7 +549,6 @@ mutate.tidyseurat <- function(.data, ...)
 }
 
  
-
 #' Rename columns
 #'
 #' Rename individual variables using `new_name = old_name` syntax.
@@ -597,7 +557,9 @@ mutate.tidyseurat <- function(.data, ...)
 #'
 #' Use the three scoped variants ([rename_all()], [rename_if()], [rename_at()])
 #' to renaming a set of variables with a function.
-#'
+#' 
+#' @importFrom dplyr rename
+#' 
 #' @inheritParams arrange
 #' @param ... <[`tidy-select`][dplyr_tidy_select]> Use `new_name = old_name`
 #'   to rename selected variables.
@@ -614,21 +576,16 @@ mutate.tidyseurat <- function(.data, ...)
 #'
 #' The following methods are currently available in loaded packages:
 #' @family single table verbs
+#' 
+#' @rdname dplyr-methods
+#' @name rename
+#' 
 #' @export
 #' @examples
 #' `%>%` = magrittr::`%>%`
 #' pbmc_small %>% tidy %>% rename(s_score = nFeature_RNA) 
 #' 
-#' @export
-rename <- function(.data, ...) {
-  UseMethod("rename")
-}
-
-#' @export
-rename.default <-  function(.data, ...)
-{
-  dplyr::rename(.data, ...)
-}
+NULL
 
 #' @export
 rename.tidyseurat <- function(.data, ...)
@@ -663,36 +620,32 @@ rename.tidyseurat <- function(.data, ...)
 #' use \code{[[1]]}. This makes `summarise()` on a rowwise tbl
 #' effectively equivalent to [plyr::ldply()].
 #'
+#' @importFrom dplyr rowwise
+#' 
 #' @param .data Input data frame.
-#'
+#' @param ... See dplyr::rowwise
+#' 
 #' @return A `tbl`
 #'
 #'   A `tbl`
 #'
+#' @rdname dplyr-methods
+#' @name rowwise
+#' 
 #' @export
 #' @examples
 #' `%>%` = magrittr::`%>%`
 #' 
- 
-#' @export
-rowwise <- function(.data) {
-  UseMethod("rowwise")
-}
+NULL
 
 #' @export
-rowwise.default <-  function(.data)
-{
-  dplyr::rowwise(.data)
-}
-
-#' @export
-rowwise.tidyseurat <- function(.data)
+rowwise.tidyseurat <- function(data, ...)
 {
   message("tidyseurat says: A data frame is returned for independent data analysis.")
   
-  .data %>%
+  data %>%
     as_tibble() %>%
-    dplyr::rowwise()
+    dplyr::rowwise(...)
   
 }
  
@@ -700,6 +653,7 @@ rowwise.tidyseurat <- function(.data)
 #' Left join datasets
 #' 
 #' @importFrom dplyr count
+#' @importFrom dplyr left_join
 #'
 #' @param x tbls to join. (See dplyr)
 #' @param y tbls to join. (See dplyr)
@@ -710,6 +664,9 @@ rowwise.tidyseurat <- function(.data)
 #'
 #' @return A tidyseurat object
 #'
+#' @rdname dplyr-methods
+#' @name left_join
+#' 
 #' @export
 #'
 #' @examples
@@ -718,16 +675,7 @@ rowwise.tidyseurat <- function(.data)
 #' tt = pbmc_small %>% tidy
 #' tt %>% left_join(tt %>% distinct(groups) %>% mutate(new_column = 1:2))
 #'
-left_join <- function (x, y, by = NULL, copy = FALSE, suffix = c(".x", ".y"),		 ...)  {
-  UseMethod("left_join")
-}
-
-#' @export
-left_join.default <-  function (x, y, by = NULL, copy = FALSE, suffix = c(".x", ".y"),
-                                ...)
-{
-  dplyr::left_join(x, y, by = by, copy = copy, suffix = suffix, ...)
-}
+NULL
 
 #' @export
 left_join.tidyseurat <- function (x, y, by = NULL, copy = FALSE, suffix = c(".x", ".y"),
@@ -758,6 +706,7 @@ left_join.tidyseurat <- function (x, y, by = NULL, copy = FALSE, suffix = c(".x"
 #' Inner join datasets
 #' 
 #' @importFrom dplyr pull
+#' @importFrom dplyr inner_join
 #'
 #' @param x tbls to join. (See dplyr)
 #' @param y tbls to join. (See dplyr)
@@ -773,16 +722,12 @@ left_join.tidyseurat <- function (x, y, by = NULL, copy = FALSE, suffix = c(".x"
 #' 
 #' tt = pbmc_small %>% tidy
 #' tt %>% inner_join(tt %>% distinct(groups) %>% mutate(new_column = 1:2) %>% slice(1))
+#' 
+#' @rdname dplyr-methods
+#' @name inner_join
+#' 
 #' @export
-inner_join <- function (x, y, by = NULL, copy = FALSE, suffix = c(".x", ".y"),		 ...)  {
-  UseMethod("inner_join")
-}
-
-#' @export
-inner_join.default <-  function (x, y, by = NULL, copy = FALSE, suffix = c(".x", ".y"),				 ...)
-{
-  dplyr::inner_join(x, y, by = by, copy = copy, suffix = suffix, ...)
-}
+NULL
 
 #' @export
 inner_join.tidyseurat <- function (x, y, by = NULL, copy = FALSE, suffix = c(".x", ".y"),		 ...)
@@ -812,6 +757,7 @@ inner_join.tidyseurat <- function (x, y, by = NULL, copy = FALSE, suffix = c(".x
 #' Right join datasets
 #' 
 #' @importFrom dplyr pull
+#' @importFrom dplyr right_join
 #'
 #' @param x tbls to join. (See dplyr)
 #' @param y tbls to join. (See dplyr)
@@ -827,23 +773,16 @@ inner_join.tidyseurat <- function (x, y, by = NULL, copy = FALSE, suffix = c(".x
 #' 
 #' tt = pbmc_small %>% tidy
 #' tt %>% right_join(tt %>% distinct(groups) %>% mutate(new_column = 1:2) %>% slice(1))
-#'
+#' 
+#' @rdname dplyr-methods
+#' @name right_join
+#' 
 #' @export
-right_join <- function (x, y, by = NULL, copy = FALSE, suffix = c(".x", ".y"),		 ...)  {
-  UseMethod("right_join")
-}
-
-#' @export
-right_join.default <-  function (x, y, by = NULL, copy = FALSE, suffix = c(".x", ".y"),
-                                 ...)
-{
-  dplyr::right_join(x, y, by = by, copy = copy, suffix = suffix, ...)
-}
+NULL
 
 #' @export
 right_join.tidyseurat <- function (x, y, by = NULL, copy = FALSE, suffix = c(".x", ".y"),
-                                 ...)
-{
+                                 ...){
 
   x %>% 
     as_tibble() %>%
@@ -871,6 +810,7 @@ right_join.tidyseurat <- function (x, y, by = NULL, copy = FALSE, suffix = c(".x
 #' Full join datasets
 #' 
 #' @importFrom dplyr pull
+#' @importFrom dplyr full_join
 #'
 #' @param x tbls to join. (See dplyr)
 #' @param y tbls to join. (See dplyr)
@@ -887,17 +827,11 @@ right_join.tidyseurat <- function (x, y, by = NULL, copy = FALSE, suffix = c(".x
 #' tt = pbmc_small %>% tidy
 #' tt %>% full_join(tibble::tibble(groups = "g1", other=1:4)) 
 #'
+#' @rdname dplyr-methods
+#' @name full_join
+#' 
 #' @export
-full_join <- function (x, y, by = NULL, copy = FALSE, suffix = c(".x", ".y"),		 ...)  {
-  UseMethod("full_join")
-}
-
-#' @export
-full_join.default <-  function (x, y, by = NULL, copy = FALSE, suffix = c(".x", ".y"),
-                                ...)
-{
-  dplyr::full_join(x, y, by = by, copy = copy, suffix = suffix, ...)
-}
+NULL
 
 #' @export
 full_join.tidyseurat <- function (x, y, by = NULL, copy = FALSE, suffix = c(".x", ".y"),
@@ -941,6 +875,8 @@ full_join.tidyseurat <- function (x, y, by = NULL, copy = FALSE, suffix = c(".x"
 #' so that (e.g.) `slice_head(df, n = 5)` will select the first five rows in
 #' each group.
 #'
+#' @importFrom dplyr slice
+#' 
 #' @details
 #' Slice does not work with relational databases because they have no
 #' intrinsic notion of row order. If you want to perform the equivalent
@@ -983,24 +919,25 @@ full_join.tidyseurat <- function (x, y, by = NULL, copy = FALSE, suffix = c(".x"
 #' * `slice_min()`: \Sexpr[stage=render,results=rd]{dplyr:::methods_rd("slice_min")}.
 #' * `slice_max()`: \Sexpr[stage=render,results=rd]{dplyr:::methods_rd("slice_max")}.
 #' * `slice_sample()`: \Sexpr[stage=render,results=rd]{dplyr:::methods_rd("slice_sample")}.
+#' 
+#' @rdname dplyr-methods
+#' @name slice
+#' 
 #' @export
 #' @examples
 #' 
 #' `%>%` = magrittr::`%>%`
 #' pbmc_small %>% tidy %>% slice(1)
-slice <- function(.data, ..., .preserve = FALSE) {
-  UseMethod("slice")
-}
-#' @export
-slice.default <-  function (.data, ..., .preserve = FALSE)
-{
-  dplyr::slice(.data, ..., .preserve = .preserve)
-}
+NULL
 
 #' @export
 slice.tidyseurat <- function (.data, ..., .preserve = FALSE)
 {
   new_meta = dplyr::slice(.data@meta.data, ..., .preserve = .preserve)
+  
+  # Error if size == 0
+  if(nrow(new_meta) == 0) stop("tidyseurat says: the resulting data container is empty. Seurat does not allow for empty containers.")
+  
   new_obj = subset(.data,   cells = rownames(new_meta ))
   #new_obj@meta.data = new_meta
   
@@ -1023,7 +960,9 @@ slice.tidyseurat <- function (.data, ..., .preserve = FALSE)
 #'
 #' ```{r, child = "man/rmd/overview.Rmd"}
 #' ```
-#'
+#' 
+#' @importFrom dplyr select
+#' 
 #' @inheritParams arrange
 #' @param ... <[`tidy-select`][dplyr_tidy_select]> One or more unquoted
 #'   expressions separated by commas. Variable names can be used as if they
@@ -1053,16 +992,12 @@ slice.tidyseurat <- function (.data, ..., .preserve = FALSE)
 #' pbmc_small %>% tidy %>% select(cell, orig.ident )
 #'
 #' @family single table verbs
+#' 
+#' @rdname dplyr-methods
+#' @name select
+#' 
 #' @export
-select <- function(.data, ...) {
-  UseMethod("select")
-}
-
-#' @export
-select.default <-  function (.data, ...)
-{
-  dplyr::select(.data, ...)
-}
+NULL
 
 #' @export
 select.tidyseurat <- function (.data, ...)
@@ -1111,6 +1046,8 @@ select.tidyseurat <- function (.data, ...)
 #' * It was easier to remove the deprecated `.env` argument.
 #' * `...` was in a suboptimal position.
 #'
+#' @importFrom dplyr sample_n
+#' 
 #' @keywords internal
 #' @param tbl A data.frame.
 #' @param size <[`tidy-select`][dplyr_tidy_select]>
@@ -1131,16 +1068,11 @@ select.tidyseurat <- function (.data, ...)
 #' 
 #' @return A tidyseurat object
 #'
+#' @rdname dplyr-methods
+#' @name sample_n
+#' 
 #' @export
-sample_n <- function(tbl, size, replace = FALSE, weight = NULL, .env = NULL, ...) {
-  UseMethod("sample_n")
-}
-
-#' @export
-sample_n.default <- function(tbl, size, replace = FALSE, weight = NULL,
-                             .env = parent.frame(), ...) {
-  tbl %>% sample_n(size, replace = replace, weight = weight, .env = .env, ...)
-}
+NULL
 
 #' @export
 sample_n.tidyseurat <- function(tbl, size, replace = FALSE,
@@ -1156,17 +1088,13 @@ sample_n.tidyseurat <- function(tbl, size, replace = FALSE,
   
 }
 
-#' @rdname sample_n
+#' @importFrom dplyr sample_frac
+#' 
+#' @rdname dplyr-methods
+#' @name sample_frac
+#' 
 #' @export
-sample_frac <- function(tbl, size = 1, replace = FALSE, weight = NULL, .env = NULL, ...) {
-  UseMethod("sample_frac")
-}
-
-#' @export
-sample_frac.default <- function(tbl, size, replace = FALSE, weight = NULL,
-                             .env = parent.frame(), ...) {
-  tbl %>% dplyr::sample_frac(size, replace = replace, weight = weight, .env = .env, ...)
-}
+NULL
 
 #' @export
 sample_frac.tidyseurat <- function(tbl, size = 1, replace = FALSE,
@@ -1257,6 +1185,8 @@ count.tidyseurat <- function(x, ..., wt = NULL, sort = FALSE, name = NULL, .drop
 #' nicer in pipes, it also works with remote data frames, and it can optionally
 #' name the output.
 #'
+#' @importFrom dplyr pull
+#' 
 #' @inheritParams arrange
 #' @inheritParams tidyselect::vars_pull
 #' @param name An optional parameter that specifies the column to be used
@@ -1270,22 +1200,18 @@ count.tidyseurat <- function(x, ..., wt = NULL, sort = FALSE, name = NULL, .drop
 #'
 #' The following methods are currently available in loaded packages:
 #' \Sexpr[stage=render,results=rd]{dplyr:::methods_rd("pull")}.
+#' 
+#' @rdname dplyr-methods
+#' @name pull
+#' 
 #' @export
 #' @examples
 #' 
 #' `%>%` = magrittr::`%>%`
 #' pbmc_small %>% tidy %>% pull(groups)
 #' 
-pull <- function(.data, var = -1, name = NULL, ...) {
-  ellipsis::check_dots_used()
-  UseMethod("pull")
-}
-#' @export
-pull.default <- function(.data, var = -1, name = NULL, ...) {
-  var = enquo(var)
-  name = enquo(name)
- .data %>% dplyr::pull( var = !!var, name = !!name, ...)
-  }
+NULL
+
 #' @export
 pull.tidyseurat <- function(.data, var = -1, name = NULL, ...) {
   var = enquo(var)
