@@ -16,6 +16,8 @@
 #'   [`ts`][stats::ts()], [`table`][base::table()]
 #' * Default: Other inputs are first coerced with [base::as.data.frame()].
 #'
+#' @importFrom tibble as_tibble
+#' 
 #' @section Row names:
 #' The default behavior is to silently remove row names.
 #'
@@ -50,23 +52,13 @@
 #'   For compatibility only, do not use for new code.
 #' @return A tibble
 #' 
+#' @rdname tibble-methods
+#' @name as_tibble
+#' 
 #' @export
 #' @examples
 #' pbmc_small %>% tidy %>% as_tibble()
-as_tibble <- function(x, ...,
-                      .name_repair = c("check_unique", "unique", "universal", "minimal"),
-                      rownames = pkgconfig::get_config("tibble::rownames", NULL)) {
-  UseMethod("as_tibble")
-}
-
-#' @export
-as_tibble.default <- function(x, ...,
-                      .name_repair = c("check_unique", "unique", "universal", "minimal"),
-                      rownames = pkgconfig::get_config("tibble::rownames", NULL)) {
-  tibble::as_tibble(x, ...,
-   .name_repair = .name_repair,
-   rownames = rownames)
-}
+NULL
 
 #' @export
 #' @importFrom purrr reduce
