@@ -2,7 +2,7 @@
 #'
 #' @importFrom tidyr unnest
 #'
-#' @param .data A tbl. (See tidyr)
+#' @param data A tbl. (See tidyr)
 #' @param cols <[`tidy-select`][tidyr_tidy_select]> Columns to unnest.
 #'   If you `unnest()` multiple columns, parallel entries must be of
 #'   compatible sizes, i.e. they're either equal or length 1 (following the
@@ -31,7 +31,10 @@
 #' @param keep_empty See tidyr::unnest
 #' @param names_repair See tidyr::unnest
 #' @param ptype See tidyr::unnest
-#' 
+#' @param .drop See tidyr::unnest
+#' @param .id tidyr::unnest
+#' @param sep tidyr::unnest
+#' @param .preserve See tidyr::unnest
 #' 
 #' @return A tidyseurat objector a tibble depending on input
 #' 
@@ -42,33 +45,22 @@
 #' 
 #'
 #' @rdname tidyr-methods
+#' @name unnest
 #'
 #' @export
-unnest <- function (.data, cols, ..., keep_empty = FALSE, ptype = NULL, 
-                    names_sep = NULL, names_repair = "check_unique")  {
-  UseMethod("unnest")
-}
-
-#' @export
-#' @rdname tidyr-methods
-unnest.default <-  function (.data, cols, ..., keep_empty = FALSE, ptype = NULL, 
-                             names_sep = NULL, names_repair = "check_unique")
-{
-  cols <- enquo(cols)
-  tidyr::unnest(.data, !!cols, ..., keep_empty = keep_empty, ptype = ptype, 
-                names_sep = names_sep, names_repair = names_repair)
-}
+NULL
 
 #' @importFrom rlang quo_name
 #' @importFrom purrr imap
 #' 
 #' @export
-#' @rdname tidyr-methods
-unnest.tidyseurat_nested <- function (.data, cols, ..., keep_empty = FALSE, ptype = NULL, 
-                                    names_sep = NULL, names_repair = "check_unique")
-{ 
+unnest.tidyseurat_nested <- function(
+  data, cols, ..., keep_empty=FALSE, ptype=NULL, names_sep=NULL, 
+  names_repair="check_unique", .drop, .id, .sep, .preserve
+){
+  
   # Need this otherwise crashes map
-  .data_ = .data
+  .data_ = data
   
   cols <- enquo(cols)
 
@@ -77,18 +69,21 @@ unnest.tidyseurat_nested <- function (.data, cols, ..., keep_empty = FALSE, ptyp
       
       # If my only column to unnest is tidyseurat
       pull(., !!cols) %>% .[[1]] %>% class %>% as.character() %>% eq("tidyseurat") %>% any ~  
-        
+      {
         # Do my trick to unnest
-        mutate(., !!cols := imap(
+        list_seurat = 
+          mutate(., !!cols := imap(
           !!cols, ~ .x %>%
-            bind_cols(
+            bind_cols_(
               
               # Attach back the columns used for nesting
               .data_ %>% select(-!!cols) %>% slice(rep(.y, ncol(.x)))
             )
         )) %>%
-        pull(!!cols) %>%
-        reduce(bind_rows),
+        pull(!!cols) 
+        
+        bind_rows(list_seurat[[1]], list_seurat[2:length(list_seurat)])
+      },
       
       # Else do normal stuff
       ~ (.) %>% 
@@ -106,6 +101,7 @@ unnest.tidyseurat_nested <- function (.data, cols, ..., keep_empty = FALSE, ptyp
 #'
 #' @param .data A tbl. (See tidyr)
 #' @param ... Name-variable pairs of the form new_col = c(col1, col2, col3) (See tidyr)
+#' @param .names_sep See tidyr::nest
 #' 
 #' @return A tidyseurat objector a tibble depending on input
 #' 
@@ -115,25 +111,16 @@ unnest.tidyseurat_nested <- function (.data, cols, ..., keep_empty = FALSE, ptyp
 #' pbmc_small %>% tidy %>% nest(data = -groups) %>% unnest(data) 
 #' 
 #' @rdname tidyr-methods
+#' @name nest
 #'
 #' @export
-nest <- function (.data, ...)  {
-  UseMethod("nest")
-}
-
-#' @export
-#' @rdname tidyr-methods
-nest.default <-  function (.data, ...)
-{
-  tidyr::nest(.data, ...)
-}
+NULL
 
 #' @importFrom rlang enquos
 #' @importFrom rlang :=
 #' 
 #' @export
-#' @rdname tidyr-methods
-nest.tidyseurat <- function (.data, ...)
+nest.tidyseurat <- function (.data, ..., .names_sep = NULL)
 {
   my_data__ = .data
   cols <- enquos(...)
@@ -169,6 +156,8 @@ nest.tidyseurat <- function (.data, ...)
 #' each group into a new column. If the groups don't match, or the input
 #' is NA, the output will be NA.
 #'
+#' @importFrom tidyr extract
+#' 
 #' @inheritParams expand
 #' @param data A tidyseurat object
 #' @param col Column name or position. This is passed to
@@ -198,20 +187,11 @@ nest.tidyseurat <- function (.data, ...)
 #'  
 #' @importFrom tidyr extract
 #' 
+#' @rdname tidyr-methods
+#' @name extract
+#' 
 #' @export
-extract <- function  (data, col, into, regex = "([[:alnum:]]+)", remove = TRUE, 
-										 convert = FALSE, ...)   {
-	UseMethod("extract")
-}
-
-#' @export
-extract.default <-  function  (data, col, into, regex = "([[:alnum:]]+)", remove = TRUE, 
-															convert = FALSE, ...) 
-{
-	col = enquo(col)
-	tidyr::extract(col = !!col, into = into, regex = regex, remove = remove, 
-								 convert = convert, ...) 
-}
+NULL
 
 #' @export
 extract.tidyseurat <- function  (data, col, into, regex = "([[:alnum:]]+)", remove = TRUE, 
@@ -247,7 +227,10 @@ extract.tidyseurat <- function  (data, col, into, regex = "([[:alnum:]]+)", remo
 #' simpler to use and to handle more use cases. We recommend you use
 #' `pivot_longer()` for new code; `gather()` isn't going away but is no longer
 #' under active development.
-#'
+#' 
+#' @importFrom ellipsis check_dots_used
+#' @importFrom tidyr pivot_longer
+#' 
 #' @param data A data frame to pivot.
 #' @param cols <[`tidy-select`][tidyr_tidy_select]> Columns to pivot into
 #'   longer format.
@@ -307,6 +290,8 @@ extract.tidyseurat <- function  (data, col, into, regex = "([[:alnum:]]+)", remo
 #' 
 #' @return A tidyseurat objector a tibble depending on input
 #' 
+#' @name pivot_longer
+#' 
 #' @export
 #' @examples
 #' # See vignette("pivot") for examples and explanation
@@ -314,60 +299,7 @@ extract.tidyseurat <- function  (data, col, into, regex = "([[:alnum:]]+)", remo
 #' library(dplyr)
 #' pbmc_small %>% tidy %>% pivot_longer(c(orig.ident, groups), names_to = "name", values_to = "value") 
 #' 
-pivot_longer <- function(data,
-                         cols,
-                         names_to = "name",
-                         names_prefix = NULL,
-                         names_sep = NULL,
-                         names_pattern = NULL,
-                         names_ptypes = list(),
-                         names_transform = list(),
-                         names_repair = "check_unique",
-                         values_to = "value",
-                         values_drop_na = FALSE,
-                         values_ptypes = list(),
-                         values_transform = list(),
-                         ...
-) {
-  
-  ellipsis::check_dots_used()
-  UseMethod("pivot_longer")
-}
-
-#' @export
-pivot_longer.default <- function(data,
-                                 cols,
-                                 names_to = "name",
-                                 names_prefix = NULL,
-                                 names_sep = NULL,
-                                 names_pattern = NULL,
-                                 names_ptypes = list(),
-                                 names_transform = list(),
-                                 names_repair = "check_unique",
-                                 values_to = "value",
-                                 values_drop_na = FALSE,
-                                 values_ptypes = list(),
-                                 values_transform = list(),
-                                 ...
-) {
-  cols <- enquo(cols)
-  tidyr::pivot_longer(data,
-                      cols,
-                      names_to = names_to,
-                      names_prefix = names_prefix,
-                      names_sep = names_sep,
-                      names_pattern = names_pattern,
-                      names_ptypes = names_ptypes,
-                      names_transform = names_transform,
-                      names_repair = names_repair,
-                      values_to =values_to,
-                      values_drop_na = values_drop_na,
-                      values_ptypes = values_ptypes,
-                      values_transform = values_transform,
-                      ...
-  )
-  
-}
+NULL
 
 #' @export
 pivot_longer.tidyseurat <- function(data,
@@ -385,13 +317,13 @@ pivot_longer.tidyseurat <- function(data,
                                   values_transform = list(),
                                   ...
 ) {
-  cols <- enquo(cols) %>% quo_names()
+  cols <- enquo(cols) 
   
   message("tidyseurat says: A data frame is returned for independent data analysis.")
   
   data %>%
     as_tibble() %>%
-    tidyr::pivot_longer(cols,
+    tidyr::pivot_longer(!!cols,
                         names_to = names_to,
                         names_prefix = names_prefix,
                         names_sep = names_sep,
@@ -412,6 +344,8 @@ pivot_longer.tidyseurat <- function(data,
 #'
 #' Convenience function to paste together multiple columns into one.
 #'
+#' @importFrom tidyr unite
+#' 
 #' @param data A data frame.
 #' @param col The name of the new column, as a string or symbol.
 #'
@@ -430,22 +364,16 @@ pivot_longer.tidyseurat <- function(data,
 #' 
 #' @return A tidyseurat objector a tibble depending on input
 #' 
+#' @rdname tidyr-methods
+#' @name unite
+#' 
 #' @export
 #' @examples
 #' 
 #' pbmc_small %>% tidy %>% unite("new_col", c(orig.ident, groups)) 
 #' 
 #' 
-unite <- function(data, col, ..., sep = "_", remove = TRUE, na.rm = FALSE) {
-  ellipsis::check_dots_unnamed()
-  UseMethod("unite")
-}
-#' @export
-unite.default <-  function(data, col, ..., sep = "_", remove = TRUE, na.rm = FALSE)
-{
-  cols = enquo(col) 
-  tidyr::unite(data, !!cols, ..., sep = sep, remove = remove, na.rm = na.rm)
-}
+NULL
 
 #' @export
 unite.tidyseurat <- function(data, col, ..., sep = "_", remove = TRUE, na.rm = FALSE)
@@ -470,6 +398,8 @@ unite.tidyseurat <- function(data, col, ..., sep = "_", remove = TRUE, na.rm = F
 #' Given either a regular expression or a vector of character positions,
 #' `separate()` turns a single character column into multiple columns.
 #'
+#' @importFrom tidyr separate
+#' 
 #' @inheritParams extract
 #' @param sep Separator between columns.
 #'
@@ -498,25 +428,16 @@ unite.tidyseurat <- function(data, col, ..., sep = "_", remove = TRUE, na.rm = F
 #' 
 #' @return A tidyseurat objector a tibble depending on input
 #' 
+#' @rdname tidyr-methods
+#' @name separate
+#' 
 #' @export
 #' @examples
 #' 
 #'  un = pbmc_small %>% tidy %>% unite("new_col", c(orig.ident, groups)) 
 #'  un %>% separate(col = new_col, into= c("orig.ident", "groups"))
 #' 
-separate <- function(data, col, into, sep = "[^[:alnum:]]+", remove = TRUE,
-                     convert = FALSE, extra = "warn", fill = "warn", ...) {
-  ellipsis::check_dots_used()
-  UseMethod("separate")
-}
-#' @export
-separate.default <-  function(data, col, into, sep = "[^[:alnum:]]+", remove = TRUE,
-                              convert = FALSE, extra = "warn", fill = "warn", ...)
-{
-  cols = enquo(col)
-  tidyr::separate(data, !!cols, into = into, sep = sep, remove = remove,
-                  convert = convert, extra = extra, fill = fill, ...)
-}
+NULL
 
 #' @export
 separate.tidyseurat <- function(data, col, into, sep = "[^[:alnum:]]+", remove = TRUE,
